emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master abd0982: Don't end non-hook variable with "-hook" (


From: Noam Postavsky
Subject: [Emacs-diffs] master abd0982: Don't end non-hook variable with "-hook" (Bug#26623)
Date: Sat, 20 May 2017 19:12:46 -0400 (EDT)

branch: master
commit abd098200bfba2577dfff800f27d5474f13cc1f3
Author: Noam Postavsky <address@hidden>
Commit: Noam Postavsky <address@hidden>

    Don't end non-hook variable with "-hook" (Bug#26623)
    
    * lisp/follow.el (follow-inside-post-command-hook-call): Renamed from
    follow-inside-post-command-hook, update uses.
---
 lisp/follow.el | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/lisp/follow.el b/lisp/follow.el
index db3b282..5dd74f3 100644
--- a/lisp/follow.el
+++ b/lisp/follow.el
@@ -340,7 +340,7 @@ property `follow-mode-use-cache' to non-nil.")
 (defvar follow-inactive-menu nil
   "The menu visible when Follow mode is inactive.")
 
-(defvar follow-inside-post-command-hook nil
+(defvar follow-inside-post-command-hook-call nil
   "Non-nil when inside Follow modes `post-command-hook'.
 Used by `follow-window-size-change'.")
 
@@ -1277,7 +1277,7 @@ non-first windows in Follow mode."
 (defun follow-post-command-hook ()
   "Ensure that the windows in Follow mode are adjacent after each command."
   (unless (input-pending-p)
-    (let ((follow-inside-post-command-hook t)
+    (let ((follow-inside-post-command-hook-call t)
          (win (selected-window)))
       ;; Work in the selected window, not in the current buffer.
       (with-current-buffer (window-buffer win)
@@ -1519,14 +1519,14 @@ non-first windows in Follow mode."
 ;; Since `follow-window-size-change' can be called indirectly from
 ;; `follow-post-command-hook' we have a potential infinite loop.  To
 ;; avoid this, we simply do not do anything in this situation.  The
 ;; variable `follow-inside-post-command-hook' contains information
 ;; about whether the execution actually is inside the
 ;; post-command-hook or not.
 
 (defun follow-window-size-change (frame)
   "Redraw all windows in FRAME, when in Follow mode."
   ;; Below, we call `post-command-hook'.  Avoid an infloop.
-  (unless follow-inside-post-command-hook
+  (unless follow-inside-post-command-hook-call
     (save-current-buffer
       (let ((orig-frame (selected-frame)))
         (select-frame frame)
@@ -1519,14 +1519,14 @@ non-first windows in Follow mode."
 ;; `follow-post-command-hook' we have a potential infinite loop.  To
 ;; avoid this, we simply do not do anything in this situation.  The
-;; variable `follow-inside-post-command-hook' contains information
-;; about whether the execution actually is inside the
+;; variable `follow-inside-post-command-hook-call' contains
+;; information about whether the execution actually is inside the
 ;; post-command-hook or not.
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]